@@ -1,17 +1,17 @@
 ;(function(){
   var map = {
-  "commitId": "631b5438e9b4572fa12be34332673078190ee2fa",
+  "commitId": "1e9d764a2206cf61f9390ed0376a1d006946cbc0",
   "branchName": "release",
-  "buildTime": "Fri, 09 Dec 2022 08:23:59 GMT",
-  "buildVersion": "5.1.259",
+  "buildTime": "Wed, 21 Dec 2022 11:00:25 GMT",
+  "buildVersion": "264",
   "css": [
     "@zoom/client-calendar/static/css/vendors~app.b826cb0e.css",
-    "@zoom/client-calendar/static/css/app.c62cfb39.css"
+    "@zoom/client-calendar/static/css/app.6d6add54.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/vendors~app.67e78cf1.js",
-    "@zoom/client-calendar/static/js/zoomUI~app.5415c834.js",
-    "@zoom/client-calendar/static/js/app.d961f764.js"
+    "@zoom/client-calendar/static/js/vendors~app.0faa88e1.js",
+    "@zoom/client-calendar/static/js/zoomUI~app.b0473b30.js",
+    "@zoom/client-calendar/static/js/app.21474ea4.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
