@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "253cec94b36683a52e7e9c7cc85358902e874c51",
-  "branchName": "release-client-5.12.x",
-  "buildTime": "Mon, 21 Nov 2022 06:45:42 GMT",
-  "buildVersion": "5.1.148",
+  "commitId": "0b39fc545fd873d1e91002e7017df56f71f75671",
+  "branchName": "release",
+  "buildTime": "Thu, 15 Dec 2022 14:37:43 GMT",
+  "buildVersion": "5.1.164",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.7f57ae19.css",
     "@zoom/client-scheduler/static/css/index.e12145da.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.4c3b92cb.js",
-    "@zoom/client-scheduler/static/js/index.35f877a9.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.73f97f40.js",
+    "@zoom/client-scheduler/static/js/index.475fe986.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
